Changelog
=========

### v0.0.2 / 2021-02-22

##### Features

  - Add decorator `superuser_required_or_403()` (#9).

##### Improvements

  - Add Python 3.9 support (#7).
  
##### Misc

  - Add release workflow to PyPI with GitHub Actions.
  - Add project urls in `setup.py` metadata (#10).
  - Tweak black and isort config (#5, #6, #8).

### v0.0.1 / 2021-02-08

  - First version, released on an unsuspecting world.
